============
 Discussion
============

This section discusses features which are under active development and not yet
fully implemented. 

Contents:

.. toctree::
   :maxdepth: 2

   base_classes
   interval_object
   time_series_access
   multitaper_jackknife
